@@ -1,4 +1,5 @@
 # (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 Fujitsu LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,10 +18,11 @@
 
 import mock
 import time
-import unittest
 
 from monasca_notification import notification as m_notification
-from monasca_notification.processors import notification_processor
+from monasca_notification.plugins import email_notifier
+from monasca_notification.processors import notification_processor as np
+from tests import base
 
 
 class smtpStub(object):
@@ -36,49 +38,43 @@ class requestsResponse(object):
         self.status_code = status
 
 
-class TestNotificationProcessor(unittest.TestCase):
+class TestNotificationProcessor(base.BaseTestCase):
 
     def setUp(self):
+        super(TestNotificationProcessor, self).setUp()
         self.trap = []
-        self.email_config = {'server': 'my.smtp.server',
-                             'port': 25,
-                             'user': None,
-                             'password': None,
-                             'timeout': 60,
-                             'from_addr': 'hpcs.mon@hp.com'}
 
-        self.mysql_config = {'ssl': None,
-                             'host': 'mysql_host',
-                             'port': 'mysql_port',
-                             'user': 'mysql_user',
-                             'db': 'dbname',
-                             'passwd': 'mysql_passwd'}
+        email_notifier.register_opts(base.config.CONF)
 
-    def tearDown(self):
-        pass
+        self.conf_default(group='email_notifier', server='my.smtp.server',
+                          port=25, user=None, password=None,
+                          timeout=60, from_addr='hpcs.mon@hp.com')
+        self.conf_default(group='mysql', ssl=None, host='localhost',
+                          port='3306', user='mysql_user', db='dbname',
+                          passwd='mysql_passwd')
+        self.conf_default(group='statsd', host='localhost', port=8125)
+
+        self.conf_default(group='notification_types', enabled=[])
 
     # ------------------------------------------------------------------------
     # Test helper functions
     # ------------------------------------------------------------------------
     @mock.patch('pymysql.connect')
-    @mock.patch('monasca_notification.processors.notification_processor.monascastatsd')
+    @mock.patch('monasca_notification.common.utils.monascastatsd')
     @mock.patch('monasca_notification.types.notifiers.email_notifier.smtplib')
     @mock.patch('monasca_notification.processors.notification_processor.notifiers.log')
     def _start_processor(self, notifications, mock_log, mock_smtp, mock_statsd, mock_pymsql):
         """Start the processor with the proper mocks
         """
-        # Since the log runs in another thread I can mock it directly, instead change the methods to put to a queue
+        # Since the log runs in another thread I can mock it directly,
+        # instead change the methods to put to a queue
         mock_log.warn = self.trap.append
         mock_log.error = self.trap.append
 
         mock_smtp.SMTP = self._smtpStub
 
-        config = {}
-        config["email"] = self.email_config
-        config["mysql"] = self.mysql_config
-        config["notification_types"] = {}
-
-        processor = (notification_processor.NotificationProcessor(config))
+        np.NotificationProcessor.insert_configured_plugins = mock.Mock()
+        processor = np.NotificationProcessor()
         processor.send(notifications)
 
     def _smtpStub(self, *arg, **kwargs):
@@ -97,7 +93,8 @@ class TestNotificationProcessor(unittest.TestCase):
                       "timestamp": time.time(),
                       "metrics": metric}
 
-        notification = m_notification.Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = m_notification.Notification(
+            0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
 
         self._start_processor([notification])
 
@@ -108,9 +105,18 @@ class TestNotificationProcessor(unittest.TestCase):
     def test_invalid_notification(self):
         """Verify invalid notification type is rejected.
         """
-        alarm_dict = {"tenantId": "0", "alarmId": "0", "alarmName": "test Alarm", "oldState": "OK", "newState": "ALARM",
-                      "stateChangeReason": "I am alarming!", "timestamp": time.time(), "metrics": "cpu_util",
-                      "severity": "LOW", "link": "http://some-place.com", "lifecycleState": "OPEN"}
+        alarm_dict = {
+            "tenantId": "0",
+            "alarmId": "0",
+            "alarmName": "test Alarm",
+            "oldState": "OK",
+            "newState": "ALARM",
+            "stateChangeReason": "I am alarming!",
+            "timestamp": time.time(),
+            "metrics": "cpu_util",
+            "severity": "LOW",
+            "link": "http://some-place.com",
+            "lifecycleState": "OPEN"}
         invalid_notification = m_notification.Notification(0, 'invalid', 'test notification',
                                                            'me@here.com', 0, 0, alarm_dict)
 
@@ -130,8 +136,8 @@ class TestNotificationProcessor(unittest.TestCase):
 
         for msg in self.trap:
             if "From: hpcs.mon@hp.com" in msg:
-                self.assertRegexpMatches(msg, "From: hpcs.mon@hp.com")
-                self.assertRegexpMatches(msg, "To: me@here.com")
-                self.assertRegexpMatches(msg, "Content-Type: text/plain")
-                self.assertRegexpMatches(msg, "Alarm .test Alarm.")
-                self.assertRegexpMatches(msg, "On host .foo1.")
+                self.assertRegex(msg, "From: hpcs.mon@hp.com")
+                self.assertRegex(msg, "To: me@here.com")
+                self.assertRegex(msg, "Content-Type: text/plain")
+                self.assertRegex(msg, "Alarm .test Alarm.")
+                self.assertRegex(msg, "On host .foo1.")
